@@ -1,4 +1,4 @@
-/* $Id: smp.c,v 1.3.2.1 1999/09/16 21:08:55 martin Exp $ */
+/* $Id: smp.c,v 1.3.2.1.2.1 2002/01/14 00:56:50 baddog Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,8 +39,8 @@ main (int argc, char *argv [])
 	int ncpu, i;
 
 	setlocale (LC_ALL, "");
-	bindtextdomain (PACKAGE, GTOPLOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
 	
 	glibtop_get_cpu (&cpu);
 
